summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/kgameio.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:58:26 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:58:26 +0000
commit838baf3f99ec5ab81b063eb5449a3381d860f377 (patch)
treedd31abcfde08ca92e4623b8f50b3d762a87c997a /libkdegames/kgame/kgameio.h
parent2bf598bafa22fac4126fc8842df6b0119aadc0e9 (diff)
downloadtdegames-838baf3f99ec5ab81b063eb5449a3381d860f377.tar.gz
tdegames-838baf3f99ec5ab81b063eb5449a3381d860f377.zip
TQt4 port kdegames
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1236074 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdegames/kgame/kgameio.h')
-rw-r--r--libkdegames/kgame/kgameio.h29
1 files changed, 17 insertions, 12 deletions
diff --git a/libkdegames/kgame/kgameio.h b/libkdegames/kgame/kgameio.h
index 82b84740..2f4b89ab 100644
--- a/libkdegames/kgame/kgameio.h
+++ b/libkdegames/kgame/kgameio.h
@@ -52,9 +52,10 @@ class KProcess;
*
* @author Martin Heni <martin@heni-online.de>
*/
-class KDE_EXPORT KGameIO : public QObject
+class KDE_EXPORT KGameIO : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -128,7 +129,7 @@ public:
/**
* Send an input message using @ref KPlayer::forwardInput
**/
- bool sendInput(TQDataStream& stream, bool transmit = true, Q_UINT32 sender = 0);
+ bool sendInput(TQDataStream& stream, bool transmit = true, TQ_UINT32 sender = 0);
signals:
/**
@@ -177,6 +178,7 @@ private:
class KDE_EXPORT KGameKeyIO : public KGameIO
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -185,7 +187,7 @@ public:
* handler signalKeyEvent and can be used to generate
* a valid move for the player.
* Note the widget you pass to the constructor must be
* the main window of your application, e.g. view->parentWidget()
* as QT does not forward your keyevents otherwise. This means
* that this might be a different widget comapred to the one you
* use for mouse inputs!
@@ -197,9 +199,9 @@ public:
* this,TQT_SLOT(slotKeyInput(KGameIO *,TQDataStream &,TQKeyEvent *,bool *)));
* \endcode
*
* @param parent The parents widget whose keyboard events * should be grabbed
*/
- KGameKeyIO(TQWidget *parent);
+ KGameKeyIO(TQWidget *tqparent);
virtual ~KGameKeyIO();
/**
@@ -221,7 +223,7 @@ signals:
* Example:
* \code
* KPlayer *player=input->player(); // Get the player
- * Q_INT32 key=e->key();
+ * TQ_INT32 key=e->key();
* stream << key;
* eatevent=true;
* \endcode
@@ -248,6 +250,7 @@ protected:
class KDE_EXPORT KGameMouseIO : public KGameIO
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -262,10 +265,10 @@ public:
* this,TQT_SLOT(slotMouseInput(KGameIO *,TQDataStream &,TQMouseEvent *,bool *)));
* \endcode
*
* @param parent The widget whose events should be captured
* @param trackmouse enables mouse tracking (gives mouse move events)
*/
- KGameMouseIO(TQWidget *parent,bool trackmouse=false);
+ KGameMouseIO(TQWidget *tqparent,bool trackmouse=false);
virtual ~KGameMouseIO();
/**
@@ -291,7 +294,7 @@ signals:
* Example:
* \code
* KPlayer *player=input->player(); // Get the player
- * Q_INT32 button=e->button();
+ * TQ_INT32 button=e->button();
* stream << button;
* eatevent=true;
* \endcode
@@ -323,6 +326,7 @@ protected:
class KDE_EXPORT KGameProcessIO : public KGameIO
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -364,7 +368,7 @@ public:
* @param receiver - not used
* @param sender - who send the message
*/
- void sendMessage(TQDataStream &stream,int msgid, Q_UINT32 receiver, Q_UINT32 sender);
+ void sendMessage(TQDataStream &stream,int msgid, TQ_UINT32 receiver, TQ_UINT32 sender);
/**
* Send a system message to the process. This is analogous to the sendMessage
@@ -376,7 +380,7 @@ public:
* @param receiver - not used
* @param sender - who send the message
*/
- void sendSystemMessage(TQDataStream &stream, int msgid, Q_UINT32 receiver, Q_UINT32 sender);
+ void sendSystemMessage(TQDataStream &stream, int msgid, TQ_UINT32 receiver, TQ_UINT32 sender);
/**
* Init this device by setting the player and e.g. sending an
@@ -403,7 +407,7 @@ public:
/**
* Internal ~ombined function for all message handling
**/
- void sendAllMessages(TQDataStream &stream,int msgid, Q_UINT32 receiver, Q_UINT32 sender, bool usermsg);
+ void sendAllMessages(TQDataStream &stream,int msgid, TQ_UINT32 receiver, TQ_UINT32 sender, bool usermsg);
protected slots:
/**
@@ -477,6 +481,7 @@ private:
class KDE_EXPORT KGameComputerIO : public KGameIO
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -185,7 +187,7 @@ public:
* a valid move for the player.
* Note the widget you pass to the constructor must be
- * the main window of your application, e.g. view->parentWidget()
+ * the main window of your application, e.g. view->tqparentWidget()
* as QT does not forward your keyevents otherwise. This means
* that this might be a different widget comapred to the one you
@@ -197,9 +199,9 @@ public:
* \endcode
*
- * @param parent The parents widget whose keyboard events * should be grabbed
+ * @param tqparent The tqparents widget whose keyboard events * should be grabbed
*/
@@ -262,10 +265,10 @@ public:
* \endcode
*
- * @param parent The widget whose events should be captured
+ * @param tqparent The widget whose events should be captured
* @param trackmouse enables mouse tracking (gives mouse move events)
*/